Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(966)

Unified Diff: ash/display/display_manager.h

Issue 1133323002: Close mirroring window only when necessary (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/display/display_controller.cc ('k') | ash/display/display_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/display/display_manager.h
diff --git a/ash/display/display_manager.h b/ash/display/display_manager.h
index e7711a05865670d6e54968f85b36bbd1a6c6f21d..b6ac0926c04b02aadc48480b33c033d31bac00d6 100644
--- a/ash/display/display_manager.h
+++ b/ash/display/display_manager.h
@@ -65,8 +65,8 @@ class ASH_EXPORT DisplayManager
virtual void CreateOrUpdateMirroringDisplay(
const DisplayInfoList& display_info_list) = 0;
- // Closes the mirror window if exists.
- virtual void CloseMirroringDisplay() = 0;
+ // Closes the mirror window if not necessary.
+ virtual void CloseMirroringDisplayIfNotNecessary() = 0;
// Called before and after the display configuration changes.
// When |clear_focus| is true, the implementation should
@@ -343,7 +343,7 @@ private:
// Creates software mirroring display related information. The display
// used to mirror the content is removed from the |display_info_list|.
- void CreateSoftwareMirroringDisplay(DisplayInfoList* display_info_list);
+ void CreateSoftwareMirroringDisplayInfo(DisplayInfoList* display_info_list);
gfx::Display* FindDisplayForId(int64 id);
« no previous file with comments | « ash/display/display_controller.cc ('k') | ash/display/display_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698